@@ -1,14 +1,15 @@
+## File Name: tam_mml_3pl_calc_prob.R
+## File Version: 1.25
+## File Last Change: 2017-08-17 18:21:53
 
 #####################################################################
 # calc_prob
 # Calculation of probabilities
 tam_mml_3pl_calc_prob <- function(iIndex, A, AXsi, B, xsi, theta, 
-           nnodes, maxK, recalc=TRUE , guess)
+           nnodes, maxK, recalc=TRUE , guess, subtract_max = TRUE )
 {		   
+
     if(recalc){
-     # AXsi.tmp <- array( tensor::tensor( A[iIndex,,, drop = FALSE], xsi, 3, 1 ) , 
-     #                    dim = c( length(iIndex) , maxK , nnodes ) )
-						 
 		LI <- length(iIndex)
 		LXsi <- dim(A)[3]
 		AXsi.tmp <- array( 0 , dim = c( LI , maxK , nnodes ) )
@@ -20,7 +21,7 @@ tam_mml_3pl_calc_prob <- function(iIndex, A, AXsi, B, xsi, theta,
     } else {
 		AXsi.tmp <- array( AXsi, dim = c( length(iIndex) , maxK , nnodes ) )
     }
-	
+
     Btheta <- array(0, dim = c(length(iIndex) , maxK , nnodes) )
     for( dd in 1:ncol(theta) ){  
 		Btheta <- Btheta + array(B[iIndex,,dd ,drop = FALSE] %o% theta[,dd] , dim = dim(Btheta))
@@ -30,19 +31,26 @@ tam_mml_3pl_calc_prob <- function(iIndex, A, AXsi, B, xsi, theta,
 	#				dims=1 , na.rm = TRUE) ,    maxK ), dim=dim(rr)[c(1,3,2)] ) , c(1,3,2) )
 
 	#*** subtract maximum and use in Rcpp
-	rr0 <- Btheta + AXsi.tmp		
-	rr1 <- tam_calc_prob_helper_subtract_max( rr0=rr0 )
-	rr <- exp(rr1)
+	rr0 <- Btheta + AXsi.tmp	
+	if ( subtract_max){
+		rr1 <- tam_calc_prob_helper_subtract_max( rr0=rr0 )
+	} else {
+		rr1 <- rr0
+	}
+	
+	rr <- exp(rr1)		
     rprobs <- rr / aperm( array( rep( colSums( aperm( rr , c(2,1,3) ) ,
 					dims=1 , na.rm = TRUE) ,  maxK ), dim=dim(rr)[c(1,3,2)] ) , c(1,3,2) )							
+			
 	# include guessing	
 	rprobs0 <- rprobs
+	
 	ind <- which(guess[ iIndex ] > 1E-6 )
 	if ( length(ind) > 0 ){
 		rprobs[ ind , 2 , ] <- guess[ind] + ( 1-guess[ind] ) * rprobs0[ind,2,]	
-		# include guessing here
 		rprobs[ ind , 1 , ] <- 1 - rprobs[ ind , 2 , ]
 	}						
+	
     return(list("rprobs" = rprobs, "AXsi" = AXsi , "rprobs0"=rprobs0 ))
 }
 ##############################################################################
