@@ -1,10 +1,13 @@
+## File Name: tam_mml_inits_xsi.R
+## File Version: 0.04
+## File Last Change: 2017-09-15 17:32:33
 
 tam_mml_inits_xsi <- function(A, resp.ind, ItemScore, xsi.inits, xsi.fixed ,
 		est.xsi.index, pweights, xsi.start0, xsi, resp, addnumb = .5 )
 {
 
     # starting values for xsi
-    maxAi <-  - (apply(-(A) , 3 , rowMaxs , na.rm=TRUE) )  
+    maxAi <-  - (apply(-(A) , 3 , tam_rowMaxs , na.rm=TRUE) )  
     personMaxA <- resp.ind %*% maxAi
 	ItemMax <- crossprod( personMaxA , pweights ) 
 
@@ -36,4 +39,4 @@ tam_mml_inits_xsi <- function(A, resp.ind, ItemScore, xsi.inits, xsi.fixed ,
 	#--- OUTPUT
 	res <- list(xsi=xsi, personMaxA=personMaxA, ItemMax=ItemMax, equal.categ=equal.categ)
 	return(res)	
-}
\ No newline at end of file
+}
