@@ -1,9 +1,13 @@
+## File Name: tam_pv_mcmc_theta_MH_ratio_accept.R
+## File Version: 0.07
+## File Last Change: 2017-08-16 11:17:40
 
-tam_pv_mcmc_theta_MH_ratio_accept <- function(loglike, dens_theta,
-	loglike_new, dens_theta_new, theta_acceptance_MH, theta, theta_new)
+tam_pv_mcmc_theta_MH_ratio_accept <- function(loglike, log_dens_theta,
+	loglike_new, log_dens_theta_new, theta_acceptance_MH, theta, theta_new)
 {
-	nstud <- length(dens_theta)
-	MH_ratio <- exp( log( loglike_new ) + log( dens_theta_new ) - log( loglike ) - log( dens_theta ) )		
+	nstud <- length(log_dens_theta)
+	eps <- 1E-100
+	MH_ratio <- exp( log( loglike_new + eps ) + log_dens_theta_new - log( loglike + eps ) - log_dens_theta  )		
 	accept_MH <- ( MH_ratio > stats::runif(nstud) )
 	loglike[ accept_MH ] <- loglike_new[ accept_MH ]
 	theta_acceptance_MH$n_samples <- theta_acceptance_MH$n_samples + 1
@@ -14,4 +18,4 @@ tam_pv_mcmc_theta_MH_ratio_accept <- function(loglike, dens_theta,
 	res <- list(loglike=loglike, theta=theta, deviance=deviance,
 				theta_acceptance_MH=theta_acceptance_MH )
 	return(res)
-}	
\ No newline at end of file
+}	
