@@ -1,6 +1,10 @@
+## File Name: tamcat.R
+## File Version: 9.04
+## File Last Change: 2017-09-15 17:25:43
 
 ######################################################
-tamcat <- function( label , time0 , active ){
+tamcat <- function( label , time0 , active )
+{
 	if (active){
 		z0 <- time0
 		cat( label , "  " )
@@ -8,9 +12,9 @@ tamcat <- function( label , time0 , active ){
 		print(z1-z0)
 		z0 <- z1 	
 		zout <- z0
-			} else {
+	} else {
 		zout <- NULL
-				}
+	}
 	return(zout)
-		}
+}
 ######################################################	
